@@ -4,7 +4,8 @@ set -euf
 
 git config --global --add safe.directory /chezmoi
 
-GO=${GO:-go}
+export GO="${GO:-go}"
+export GOTOOLCHAIN=auto
 
 if [ -d "/go-cache" ]; then
 	export GOCACHE="/go-cache/cache"
@@ -14,7 +15,7 @@ if [ -d "/go-cache" ]; then
 fi
 
 cd /chezmoi
-${GO} run . doctor || true
+${GO} tool chezmoi doctor || true
 ${GO} test ./...
 
 sh assets/scripts/install.sh
