@@ -12,7 +12,7 @@ import (
 	"github.com/klauspost/compress/zip"
 	vfs "github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
 )
 
 var _ System = &ZIPWriterSystem{}
