@@ -13,8 +13,9 @@ type sshCmdConfig struct {
 
 func (c *Config) newSSHCmd() *cobra.Command {
 	sshCmd := &cobra.Command{
+		GroupID: groupIDRemote,
 		Use:     "ssh host",
-		Short:   "ssh to a host and initialize dotfiles",
+		Short:   "SSH to a host and initialize dotfiles",
 		Long:    mustLongHelp("ssh"),
 		Example: example("ssh"),
 		Args:    cobra.MinimumNArgs(1),
